# Generated by Django 5.0.8 on 2024-08-21 16:03

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        (
            "dashblocks",
            "0012_rename_dashblock_org_is_active_dashblock_type_priority_dashblocks__org_id_024805_idx_and_more",
        ),
    ]

    operations = [
        migrations.RenameIndex(
            model_name="dashblock",
            new_name="dashblock_org_typ_prio_idx",
            old_name="dashblocks__org_id_024805_idx",
        ),
        migrations.RenameIndex(
            model_name="dashblocktype",
            new_name="dashblocktype_slug_name_idx",
            old_name="dashblocks__slug_c0c6c6_idx",
        ),
    ]



# Generated by Django 4.2.8 on 2023-12-05 16:51

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("dashblocks", "0011_alter_dashblock_index_together_and_more"),
    ]

    operations = [
        migrations.RenameIndex(
            model_name="dashblock",
            new_name="dashblocks__org_id_024805_idx",
            old_fields=("org", "is_active", "dashblock_type", "priority"),
        ),
        migrations.RenameIndex(
            model_name="dashblocktype",
            new_name="dashblocks__slug_c0c6c6_idx",
            old_fields=("slug", "name"),
        ),
    ]
